@@ -1,5 +1,7 @@
 import email, urllib
-from WebKit import *
+
+from WebKit import WebResource, WebArchive
+from Cocoa import NSData, NSString, NSURL
 
 def loadMHT(filename):
     """
@@ -26,15 +28,14 @@ class MHTLoader (object):
         self.loadFile(filename)
 
     def loadFile(self, filename):
-        fp = open(filename, 'r')
-        msg = email.message_from_file(fp)
-        fp.close()
+        with open(filename, "r") as fp:
+            msg = email.message_from_file(fp)
 
         for part in msg.walk():
-            if part.get_content_maintype() == 'multipart':
+            if part.get_content_maintype() == "multipart":
                 continue
 
-            filename = part.get('Content-Location')
+            filename = part.get("Content-Location")
             contentType = part.get_content_type()
             data = part.get_payload(decode=True)
 
@@ -46,8 +47,8 @@ class MHTLoader (object):
         # IE creates MHT files with file: URLS containing backslashes,
         # NSURL insists that those are invalid, replace backslashes by
         # forward slashes.
-        if url.startswith('file:'):
-            return url.replace('\\', '/')
+        if url.startswith("file:"):
+            return url.replace("\\", "/")
         else:
             return url
 
@@ -57,15 +58,16 @@ class MHTLoader (object):
         """
         rootType, rootText = self.parts[self.root]
         pageResource = WebResource.alloc().initWithData_URL_MIMEType_textEncodingName_frameName_(
-                NSData.dataWithBytes_length_(rootText.replace('\\', '/'), len(rootText)),
-                NSURL.URLWithString_(self.fixupURL(self.root)),
-                NSString.stringWithString_(rootType),
-                None,
-                None)
+            NSData.dataWithBytes_length_(rootText.replace(b"\\", b"/"), len(rootText)),
+            NSURL.URLWithString_(self.fixupURL(self.root)),
+            NSString.stringWithString_(rootType),
+            None,
+            None)
 
         resources = []
         for url in self.parts:
-            if url == self.root: continue
+            if url == self.root:
+                continue
 
             tp, data = self.parts[url]
             resources.append(WebResource.alloc().initWithData_URL_MIMEType_textEncodingName_frameName_(
@@ -76,17 +78,16 @@ class MHTLoader (object):
                 None))
 
         return WebArchive.alloc().initWithMainResource_subresources_subframeArchives_(
-                pageResource, resources, None)
+            pageResource, resources, None)
 
 
 def main():
     # Testing...
-    p = MHTLoader('audit-web.mht')
+    p = MHTLoader("python-home.mht")
     a = p.asWebArchive()
     d = a.data()
-    fp = open('audit-web.webarchive', 'wb')
-    fp.write(a.data().bytes())
-    fp.close()
+    with open("python-home.webarchive", "wb") as fp:
+        fp.write(a.data().bytes())
 
 if __name__ == "__main__":
     main()
