@@ -5,9 +5,8 @@ The PyDocEventHandler handles just the event that is used to open URLs. Thanks
 to this class you can use ``open pydoc:///os.open`` from a command-line, or
 add ``pydoc:///`` to HTML files.
 """
-from Foundation import *
+from Cocoa import NSObject, NSAppleEventManager
 
-from Carbon.AppleEvents import kAEISGetURL, kAEInternetSuite
 import struct
 import objc
 
@@ -19,7 +18,7 @@ class PyDocEventHandler (NSObject):
     urlfield = objc.IBOutlet('urlfield')
 
     def handleEvent_withReplyEvent_(self, event, replyEvent):
-        theURL = event.descriptorForKeyword_(fourCharToInt('----'))
+        theURL = event.descriptorForKeyword_(fourCharToInt(b'----'))
 
         self.urlfield.setStringValue_(theURL.stringValue())
         self.webview.takeStringURLFrom_(theURL)
@@ -34,5 +33,5 @@ class PyDocEventHandler (NSObject):
         # are wrong.
         manager.setEventHandler_andSelector_forEventClass_andEventID_(
             self, 'handleEvent:withReplyEvent:',
-                fourCharToInt('GURL'),
-                fourCharToInt('GURL'))
+                fourCharToInt(b'GURL'),
+                fourCharToInt(b'GURL'))
